Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(737)

Unified Diff: chrome/browser/resources/settings/people_page/lock_screen.js

Issue 2862613003: md settings: Show lock screen when pin/fingerprint disabled. (Closed)
Patch Set: Fix patch set 2 errors. Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/settings/people_page/lock_screen.js
diff --git a/chrome/browser/resources/settings/people_page/lock_screen.js b/chrome/browser/resources/settings/people_page/lock_screen.js
index 230fa2d552ef22aea9d46f3ef58824649c4e593a..fe5be029e66e86603bf7fd010986d95b6135aa97 100644
--- a/chrome/browser/resources/settings/people_page/lock_screen.js
+++ b/chrome/browser/resources/settings/people_page/lock_screen.js
@@ -56,13 +56,13 @@ Polymer({
},
/**
* True if pin unlock settings should be displayed on this machine.
* @private
*/
- pinUnlockEnabled_: {
+ quickUnlockEnabled_: {
type: Boolean,
value: function() {
- return loadTimeData.getBoolean('pinUnlockEnabled');
+ return loadTimeData.getBoolean('quickUnlockEnabled');
},
readOnly: true,
},
@@ -231,9 +231,12 @@ Polymer({
return selectedUnlockType === LockScreenUnlockType.PIN_PASSWORD;
},
- /** @private */
- getSetupPinText_: function() {
- if (this.hasPin)
+ /**
+ * @param {boolean} hasPin
+ * @private
+ */
+ getSetupPinText_: function(hasPin) {
+ if (hasPin)
return this.i18n('lockScreenChangePinButton');
return this.i18n('lockScreenSetupPinButton');
},
@@ -56,13 +56,13 @@ Polymer({
},
/**
- * True if pin unlock settings should be displayed on this machine.
+ * True if quick unlock settings should be displayed on this machine.
* @private
*/

Powered by Google App Engine
This is Rietveld 408576698